# eric7.SystemUtilities.SysUtilities

Module implementing System related utility functions.

### Global Attributes

None

### Classes

None

### Functions

getStandardModules | Function to get a list of modules of the standard library.

## getStandardModules

getStandardModules()

Function to get a list of modules of the standard library.

Return:
  set of builtin modules

Return Type:
  set of str

Up